@@ -6,7 +6,7 @@
 ;; Copyright (C) 2003-2006 Robert Widhopf-Fenk
 ;; Copyright (C) 2024-2025 The VM Developers
 ;;
-;; Version: 8.3.0
+;; Version: 8.3.1
 ;; Maintainer: viewmail-info@nongnu.org
 ;; URL: https://gitlab.com/emacs-vm/vm
 ;; Package-Requires: ((emacs "28.1") (vcard "0.2.2"))
@@ -95,11 +95,14 @@
   (error "VM requires Emacs %s or later" vm-min-emacs-version))
 
 
-;; Ensure that vm-autoloads is loaded in case the user is using VM
-;; autoloads 
-
-(if (not (featurep 'xemacs))
-    (require 'vm-autoloads))
+;; emacs 28 doesn't generate a provide in when generating autoloads
+;; yet does bbdb-vm.el  (require 'vm-autoloads). This workds around
+;; this issue, yet allows vm.el to work if evaluated without going through
+;; vm-autoloads.
+(if (<= emacs-major-version 28)
+    (progn
+      (load-library "vm-autoloads")
+      (provide 'vm-autoloads)))
 
 ;;;###autoload
 (cl-defun vm (&optional folder &key read-only interactive
